;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cmake-mode" "4.4.3"
  "Major-mode for editing CMake sources."
  '((emacs "24.1"))
  :commit "af7ecc8c294d153b0120813776e1fa11c5bfe4a1"
  :revdesc "v4.4.3-0-gaf7ecc8c294d")
